@@ -1,9 +1,9 @@
 package Sort::Sub;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2019-12-14'; # DATE
+our $DATE = '2019-12-15'; # DATE
 our $DIST = 'Sort-Sub'; # DIST
-our $VERSION = '0.112'; # VERSION
+our $VERSION = '0.113'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -14,8 +14,7 @@ our $re_spec = qr/\A(\$)?(\w+)(?:<(\w*)>)?\z/;
 our %argsopt_sortsub = (
     sort_sub => {
         summary => 'Name of a Sort::Sub::* module (without the prefix)',
-        schema => ['str*', match => qr/\A\$?\w+(?:<[ri]*>)?\z/],
-        # XXX add completion using Complete::Tree
+        schema => ['sortsub::spec*'],
     },
     sort_args => {
         summary => 'Arguments to pass to the Sort::Sub::* routine',
@@ -78,7 +77,7 @@ Sort::Sub - Collection of sort subroutines
 
 =head1 VERSION
 
-This document describes version 0.112 of Sort::Sub (from Perl distribution Sort-Sub), released on 2019-12-14.
+This document describes version 0.113 of Sort::Sub (from Perl distribution Sort-Sub), released on 2019-12-15.
 
 =head1 SYNOPSIS
 
